@@ -4,6 +4,7 @@ from typing import Any, List, Optional, Tuple, Union
 
 from freshbooks.api.resource import HttpVerbs, Resource
 from freshbooks.builders import Builder
+from freshbooks.builders.includes import IncludesBuilder
 from freshbooks.errors import FreshBooksError, FreshBooksNotImplementedError
 from freshbooks.models import ListResult, Result, VisState
 
@@ -65,13 +66,13 @@ class AccountingResource(Resource):
         if name in self.missing_endpoints:
             raise FreshBooksNotImplementedError(self.list_name, name)
 
-    def get(self, account_id: str, resource_id: int, builders: Optional[List[Builder]] = None) -> Result:
-        """Get a single entry with the corresponding id.
+    def get(self, account_id: str, resource_id: int, includes: Optional[IncludesBuilder] = None) -> Result:
+        """Get a single resource with the corresponding id.
 
         Args:
             account_id: The alpha-numeric account id
             resource_id: Id of the resource to return
-
+            builders: (Optional) IncludesBuilder object for including additional data, sub-resources, etc.
         Returns:
             Result: Result object with the resource's response data.
 
@@ -80,16 +81,18 @@ class AccountingResource(Resource):
         """
         self._reject_missing("get")
         resource_url = self._get_url(account_id, resource_id)
-        query_string = self._build_query_string(builders)
+        query_string = ""
+        if includes:
+            query_string = self._build_query_string([includes])
         data = self._request(f"{resource_url}{query_string}", HttpVerbs.GET)
         return Result(self.single_name, data)
 
     def list(self, account_id: str, builders: Optional[List[Builder]] = None) -> ListResult:
-        """Get a list of entries.
+        """Get a list of resources.
 
         Args:
             account_id: The alpha-numeric account id
-            builders: List of builder objects for filters, pagination, etc.
+            builders: (Optional) List of builder objects for filters, pagination, etc.
 
         Returns:
             ListResult: ListResult object with the resources response data.
@@ -104,11 +107,36 @@ class AccountingResource(Resource):
         return ListResult(self.list_name, self.single_name, data)
 
     def create(self, account_id: str, data: dict) -> Result:
+        """Create a resource.
+
+        Args:
+            account_id: The alpha-numeric account id
+            data: Dictionary of data to populate the resource
+
+        Returns:
+            Result: Result object with the new resource's response data.
+
+        Raises:
+            FreshBooksError: If the call is not successful.
+        """
         self._reject_missing("create")
         response = self._request(self._get_url(account_id), HttpVerbs.POST, data={self.single_name: data})
         return Result(self.single_name, response)
 
     def update(self, account_id: str, resource_id: int, data: dict) -> Result:
+        """Update a resource.
+
+        Args:
+            account_id: The alpha-numeric account id
+            resource_id: Id of the resource to update
+            data: Dictionary of data to update the resource to
+
+        Returns:
+            Result: Result object with the updated resource's response data.
+
+        Raises:
+            FreshBooksError: If the call is not successful.
+        """
         self._reject_missing("update")
         response = self._request(
             self._get_url(account_id, resource_id), HttpVerbs.PUT, data={self.single_name: data}
@@ -116,6 +144,21 @@ class AccountingResource(Resource):
         return Result(self.single_name, response)
 
     def delete(self, account_id: str, resource_id: int) -> Result:
+        """Delete a resource.
+
+        Note: Most FreshBooks resources are soft-deleted,
+        See [FreshBooks API - Active and Deleted Objects](https://www.freshbooks.com/api/active_deleted)
+
+        Args:
+            account_id: The alpha-numeric account id
+            resource_id: Id of the resource to delete
+
+        Returns:
+            Result: An empty Result object.
+
+        Raises:
+            FreshBooksError: If the call is not successful.
+        """
         self._reject_missing("delete")
         if self.delete_via_update:
             response = self._request(
